=============================
Django Balystic
=============================

.. image:: https://badge.fury.io/py/django-balystic.png
    :target: https://badge.fury.io/py/django-balystic

.. image:: https://travis-ci.org/inqbation/django-balystic.png?branch=master
    :target: https://travis-ci.org/inqbation/django-balystic

Connect to Balystic API in your Django project



Quickstart
----------

Install Django Balystic::

    pip install django-balystic

Then use it in a project::

    import balystic

Features
--------

* TODO

Running Tests
--------------

Does the code actually work?

::

    source <YOURVIRTUALENV>/bin/activate
    (myenv) $ pip install -r requirements_test.txt
    (myenv) $ python runtests.py

Credits
---------

Tools used in rendering this package:

*  Cookiecutter_
*  `cookiecutter-djangopackage`_

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`cookiecutter-djangopackage`: https://github.com/pydanny/cookiecutter-djangopackage
